@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.84 2004/01/16 08:01:46 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.85 2004/01/17 06:36:31 fuyu Exp $
  */
 
 #include "config.h"
@@ -559,11 +559,13 @@ initialize_thread_ui(OchushaApplication *application)
 				application);
 
   /* ̤εǽ˥塼Ĥ֤ */
+#if 0
   dummy_widget = gtk_item_factory_get_widget_by_action(
 					link_popup_menu_item_factory,
 					LINK_POPUP_MENU_SAVE_LINK_AS);
   if (dummy_widget != NULL)
     gtk_widget_set_sensitive(dummy_widget, FALSE);
+#endif
 
   g_return_if_fail(tag_table == NULL);
 
@@ -840,7 +842,7 @@ link_popup_menu_callback(gpointer data, guint action, GtkWidget *widget)
       break;
 
     case LINK_POPUP_MENU_SAVE_LINK_AS:
-      fprintf(stderr, "Not implemented yet.\n");
+      ochusha_download_url(application, url);
       break;
     }
 }
