@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.31 2004/01/14 10:03:17 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.32 2004/01/16 08:01:46 fuyu Exp $
  */
 
 #include "config.h"
@@ -1250,7 +1250,6 @@ boardlist_view_do_on_selection(BoardlistView *view, int what_to_do)
   fprintf(stderr, "boardlist_view_do_on_selection: view=%p what_to_do=%d\n",
 	  view, what_to_do);
 #endif
-  MAIN_THREAD_EVENT_CALLBACK();
 
   rows = gtk_tree_selection_get_selected_rows(view->selection, NULL);
   g_list_foreach(rows, do_on_selection_helper, &args);
@@ -1267,8 +1266,6 @@ boardlist_view_do_on_selection(BoardlistView *view, int what_to_do)
       g_slist_foreach(args.hidden_categories, remove_row, view->model);
       g_slist_free(args.hidden_categories);
     }
-
-  ENTER_MAIN_EVENT_LOOP();
 }
 
 
@@ -1399,8 +1396,6 @@ boardlist_view_button_press(GtkWidget *widget, GdkEventButton *event)
 
   view = BOARDLIST_VIEW(widget);
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   if (view->last_event_path != NULL)
     {
       gtk_tree_path_free(view->last_event_path);
@@ -1455,7 +1450,6 @@ boardlist_view_button_press(GtkWidget *widget, GdkEventButton *event)
   path = NULL;
 
  done:
-  ENTER_MAIN_EVENT_LOOP();
 
   if (path != NULL)
     gtk_tree_path_free(path);
@@ -1476,8 +1470,6 @@ boardlist_view_button_release(GtkWidget *widget, GdkEventButton *event)
   g_return_val_if_fail(IS_BOARDLIST_VIEW(view), FALSE);
   g_return_val_if_fail(event != NULL, FALSE);
 
-  MAIN_THREAD_EVENT_CALLBACK();
-
   if (event->button != 3 && view->last_event_path != NULL)
     {
       int row_type;
@@ -1533,8 +1525,6 @@ boardlist_view_button_release(GtkWidget *widget, GdkEventButton *event)
       view->last_event_path = NULL;
     }
 
-  ENTER_MAIN_EVENT_LOOP();
-
   if (GTK_WIDGET_CLASS(parent_class)->button_release_event != NULL)
     return (*GTK_WIDGET_CLASS(parent_class)->button_release_event)(widget,
 								   event);
