@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.18 2004/01/16 08:01:46 fuyu Exp $
+ * $Id: main.c,v 1.20 2004/01/17 09:48:50 fuyu Exp $
  */
 
 #include "config.h"
@@ -213,6 +213,16 @@ main(int argc, char *argv[])
   if (resource_file != NULL)
     {
       gtk_rc_parse(resource_file);
+      gtk_rc_add_default_file(resource_file);
+      G_FREE(resource_file);
+    }
+
+  resource_file = ochusha_config_find_file(&application->config,
+					   OCHUSHA_PREFS_GTKRC, NULL);
+  if (resource_file != NULL)
+    {
+      gtk_rc_parse(resource_file);
+      gtk_rc_add_default_file(resource_file);
       G_FREE(resource_file);
     }
 
