@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.62 2004/01/15 03:27:45 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.65 2004/01/17 09:45:40 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -48,6 +48,7 @@
 #define ENABLE_MAIN_TOOLBAR						0
 
 #define OCHUSHA_GTKRC					"ochusha-gtkrc"
+#define OCHUSHA_PREFS_GTKRC				"ochusha-prefs-gtkrc"
 #define OCHUSHA_BOOKMARK_XML				"bookmark.xml.gz"
 #define OCHUSHA_SESSION_XML				"session.xml.gz"
 #define OCHUSHA_INIT_SCM				"ochusha-init.scm"
@@ -273,6 +274,9 @@ struct _OchushaApplication
   /* Ǹν񤭹߻Υᥤ */
   gchar *last_mail;
 
+  /* ǸΥɥǥ쥯ȥ */
+  char *last_download_directory;
+
   /* ˽λɤ */
   gboolean shutdown_succeeded;
   gboolean recover_mode;
@@ -317,6 +321,8 @@ typedef enum
   MAIN_MENU_HIDE_HIDDEN_THREADS,
   MAIN_MENU_DEBUG_CONSOLE,
   MAIN_MENU_OPTIONS,
+  MAIN_MENU_SELECT_BOARDLIST_THREADLIST_FONTS,
+  MAIN_MENU_SELECT_THREAD_FONTS,
   MAIN_MENU_ABOUT,
 } OchushaMainMenuAction;
 
@@ -331,6 +337,7 @@ void ochusha_clipboard_set_text(OchushaApplication *application,
 
 void ochusha_open_url(OchushaApplication *application, const char *url,
 		      gboolean in_tab, gboolean use_web_browser);
+void ochusha_download_url(OchushaApplication *application, const char *url);
 #if ENABLE_MAIN_TOOLBAR
 void set_current_url(OchushaApplication *application, const char *url);
 const char *get_current_url(OchushaApplication *application);
