@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.34 2004/01/15 02:08:58 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.35 2004/01/16 08:00:01 fuyu Exp $
  */
 
 #include "config.h"
@@ -52,10 +52,7 @@
 #include <zlib.h>
 
 
-#define ANALYSIS_INTERVAL	50
-
-
-static OchushaBulletinBoardClass *parent_class = NULL;
+#define ANALYSIS_INTERVAL	200
 
 
 static void ochusha_board_2ch_class_init(OchushaBoard2chClass *klass);
@@ -142,6 +139,10 @@ ochusha_board_2ch_get_type(void)
 }
 
 
+static OchushaBulletinBoardClass *parent_class = NULL;
+static GQuark idle_checker_id;
+
+
 static void
 ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
 {
@@ -176,6 +177,8 @@ ochusha_board_2ch_class_init(OchushaBoard2chClass *klass)
     = ochusha_board_2ch_create_new_thread;
 
   klass->get_read_cgi_url = NULL;
+
+  idle_checker_id = g_quark_from_static_string("OchushaBoard2ch::IdleChecker");
 }
 
 
@@ -547,6 +550,7 @@ ochusha_board_2ch_lookup_kako_thread_by_url(OchushaBulletinBoard *board,
 		}
 	      else
 		{
+		  g_hash_table_remove(board->thread_table, thread_id);
 		  OCHU_OBJECT_UNREF(thread);
 		  thread = NULL;
 		}
@@ -927,7 +931,7 @@ undo_thread_ref(gpointer data, gpointer user_data)
 static gboolean
 advance_parsing(gpointer data)
 {
-  g_object_set_data(G_OBJECT(data), "checker", NULL);
+  g_object_set_qdata(G_OBJECT(data), idle_checker_id, NULL);
   ochusha_async_buffer_broadcast((OchushaAsyncBuffer *)data);
   OCHU_OBJECT_UNREF(data);
   return FALSE;
@@ -1120,58 +1124,43 @@ refresh_threadlist_by_subject_txt(OchushaBulletinBoard *board,
 	if (interval > 0)
 	  {
 	    unsigned int old_len = buffer->length;
-	    if (ochusha_async_buffer_is_busy(buffer))
-	      do
-		{
-		  if (!ochusha_async_buffer_wait(buffer))
-		    {
+	    do
+	      {
+		if (!ochusha_async_buffer_wait(buffer))
+		  {
 #if DEBUG_ASYNC_BUFFER_MOST
-		      fprintf(stderr, "buffer has been terminated.\n");
+		    fprintf(stderr, "buffer has been terminated.\n");
 #endif
-		      goto terminated;
-		    }
-		} while (old_len > buffer->length && !buffer->fixed);
+		    goto terminated;
+		  }
+	      } while (old_len > buffer->length && !buffer->fixed);
 	  }
 	else
 	  {
+	    /*
+	     * GUIΥ쥹ݥ󥹤βܻؤ¸
+	     */
 #if 0
-	    if (ochusha_async_buffer_is_busy(buffer))
+	    int count = 0;
+#endif
+	    OCHU_OBJECT_REF(buffer);
+	    g_object_set_qdata(G_OBJECT(buffer), idle_checker_id, buffer);
+	    g_idle_add_full(G_PRIORITY_HIGH_IDLE + 30,
+			    advance_parsing, buffer, NULL);
+	    do
 	      {
-		/*
-		 * buffer˥륹åɤsuspend/terminate
-		 * ȿ뤿˥å
-		 */
+#if 0
+		count++;
+#endif
 		if (!ochusha_async_buffer_wait(buffer))
 		  goto terminated;
-	      }
-	    else
-#endif
-	      {
-		/*
-		 * GUIΥ쥹ݥ󥹤βܻؤ¸
-		 */
+	      } while (g_object_get_qdata(G_OBJECT(buffer),
+					  idle_checker_id) != NULL);
 #if 0
-		int count = 0;
+	    fprintf(stderr, "count=%d\n", count);
 #endif
-		OCHU_OBJECT_REF(buffer);
-		g_object_set_data(G_OBJECT(buffer), "checker", buffer);
-		g_idle_add_full(G_PRIORITY_HIGH_IDLE + 15,
-				advance_parsing, buffer, NULL);
-		do
-		  {
-#if 0
-		    count++;
-#endif
-		    if (!ochusha_async_buffer_wait(buffer))
-		      goto terminated;
-		  } while (g_object_get_data(G_OBJECT(buffer), "checker")
-			   != NULL);
-#if 0
-		fprintf(stderr, "count=%d\n", count);
-#endif
-	      }
-	    interval = ANALYSIS_INTERVAL;
 	  }
+	interval = ANALYSIS_INTERVAL;
 
 	if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_DIRTY)
 	  {
