@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_jbbs.c,v 1.10 2004/01/14 09:59:48 fuyu Exp $
+ * $Id: ochusha_board_jbbs.c,v 1.11 2004/01/16 08:00:01 fuyu Exp $
  */
 
 #include "config.h"
@@ -53,9 +53,6 @@
 #include <unistd.h>
 
 
-static OchushaBoard2chClass *parent_class = NULL;
-
-
 static void ochusha_board_jbbs_class_init(OchushaBoardJBBSClass *klass);
 static void ochusha_board_jbbs_init(OchushaBoardJBBS *board);
 
@@ -128,6 +125,10 @@ ochusha_board_jbbs_get_type(void)
 }
 
 
+static OchushaBoard2chClass *parent_class = NULL;
+static GQuark idle_checker_id;
+
+
 static void
 ochusha_board_jbbs_class_init(OchushaBoardJBBSClass *klass)
 {
@@ -152,6 +153,9 @@ ochusha_board_jbbs_class_init(OchushaBoardJBBSClass *klass)
     = ochusha_board_jbbs_create_new_thread;
 
   class_2ch->get_read_cgi_url = ochusha_board_jbbs_get_read_cgi_url;
+
+  idle_checker_id
+    = g_quark_from_static_string("OchushaBoardJBBS::IdleChecker");
 }
 
 
