@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.23 2004/01/14 14:45:22 fuyu Exp $
+ * $Id: utils.c,v 1.24 2004/01/17 07:52:25 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION
@@ -39,6 +39,10 @@
 #include <langinfo.h>
 #endif
 
+#if HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #include <fcntl.h>
 #include <limits.h>
 
@@ -493,8 +497,12 @@ ochusha_utils_get_utc_time(const char *date_string)
 
   if (lc_time == NULL)
     {
+#if HAVE_LOCALE_H
       lc_time = setlocale(LC_TIME, "C");
       g_return_val_if_fail(lc_time != NULL, -1);
+#else
+      return -1;
+#endif
     }
 
   g_return_val_if_fail(date_string != NULL && *date_string != '\0', -1);
